@@ -27,8 +27,7 @@
 #' @return A `tbl_summary` object
 #' @examples
 #' tbl_n_ex <-
-#'   trial %>%
-#'   dplyr::select(trt, age, grade, response) %>%
+#'   trial[c("trt", "age", "grade", "response")] %>%
 #'   tbl_summary(by = trt) %>%
 #'   add_n()
 #' @section Example Output:
@@ -37,7 +36,7 @@
 add_n <- function(x, statistic = "{n}", col_label = "**N**", footnote = FALSE,
                   last = FALSE, missing = NULL) {
   # checking that input is class tbl_summary
-  if (class(x) != "tbl_summary") stop("x must be class 'tbl_summary'")
+  if (!inherits(x, "tbl_summary")) stop("`x` must be class 'tbl_summary'")
 
   # defining function to round percentages -------------------------------------
   percent_fun <- getOption("gtsummary.tbl_summary.percent_fun",
