@@ -18,7 +18,7 @@
 #' the outcome in a univariate regression model. Take care using the `x` argument
 #' that each of the columns in the data frame are appropriate for the same type
 #' of model, e.g. they are all continuous variables appropriate for [lm], or
-#' binary variables appropriate for logistic regression with [glm].
+#' dichotomous variables appropriate for logistic regression with [glm].
 #'
 #' @inheritSection tbl_regression Setting Defaults
 #' @inheritSection tbl_regression Note
@@ -32,7 +32,7 @@
 #' @param x Model covariate (e.g. `x = trt`).
 #' All other columns in `data` will serve as the outcome in a regression model
 #' with `x` as a covariate.  Output table is best when `x` is a continuous or
-#' binary variable displayed on a single row.
+#' dichotomous variable displayed on a single row.
 #' Specify one and only one of `y` or `x`
 #' @param formula String of the model formula.
 #' Uses [glue::glue] syntax. Default is `"{y} ~ {x}"`, where `{y}`
@@ -42,7 +42,6 @@
 #' function defined by `method`.
 #' @param hide_n Hide N column. Default is `FALSE`
 #' @inheritParams tbl_regression
-#' @importFrom stringr word str_detect fixed
 #' @author Daniel D. Sjoberg
 #' @seealso See tbl_regression \href{http://www.danieldsjoberg.com/gtsummary/articles/tbl_regression.html#tbl_uvregression}{vignette}  for detailed examples
 #' @family tbl_uvregression tools
@@ -51,7 +50,7 @@
 #' @examples
 #' tbl_uv_ex1 <-
 #'   tbl_uvregression(
-#'     trial %>% dplyr::select(response, age, grade),
+#'     trial[c("response", "age", "grade")],
 #'     method = glm,
 #'     y = response,
 #'     method.args = list(family = binomial),
@@ -62,10 +61,9 @@
 #' library(survival)
 #' tbl_uv_ex2 <-
 #'   tbl_uvregression(
-#'     trial %>% dplyr::select(ttdeath, death, age, grade, response),
+#'     trial[c("ttdeath", "death", "age", "grade", "response")],
 #'     method = coxph,
 #'     y = Surv(ttdeath, death),
-#'     label = list(vars(grade) ~ "Grade"),
 #'     exponentiate = TRUE,
 #'     pvalue_fun = function(x) style_pvalue(x, digits = 2)
 #'   )
@@ -73,12 +71,10 @@
 #' # for convenience, you can also pass named lists to any arguments
 #' # that accept formulas (e.g label, etc.)
 #' library(survival)
-#' trial %>%
-#'   dplyr::select(ttdeath, death, age, grade, response) %>%
+#' trial[c("ttdeath", "death", "age", "grade", "response")] %>%
 #'   tbl_uvregression(
 #'     method = coxph,
 #'     y = Surv(ttdeath, death),
-#'     label = list(grade = "Grade"),
 #'     exponentiate = TRUE
 #'   )
 #' @section Example Output:
@@ -93,7 +89,7 @@
 tbl_uvregression <- function(data, method, y = NULL, x = NULL, method.args = NULL,
                              formula = "{y} ~ {x}",
                              exponentiate = FALSE, label = NULL,
-                             include = NULL, exclude = NULL,
+                             include = everything(), exclude = NULL,
                              hide_n = FALSE, show_single_row = NULL, conf.level = NULL,
                              estimate_fun = NULL, pvalue_fun = NULL, show_yesno = NULL,
                              tidy_fun = NULL) {
@@ -105,6 +101,19 @@ tbl_uvregression <- function(data, method, y = NULL, x = NULL, method.args = NUL
     )
   }
 
+  if (!rlang::quo_is_null(rlang::enquo(exclude))) {
+    lifecycle::deprecate_warn(
+      "1.2.5",
+      "gtsummary::tbl_uvregression(exclude = )",
+      "tbl_uvregression(include = )",
+      details = paste0(
+        "The `include` argument accepts quoted and unquoted expressions similar\n",
+        "to `dplyr::select()`. To exclude variable, use the minus sign.\n",
+        "For example, `include = -c(age, stage)`"
+      )
+    )
+  }
+
   # setting defaults -----------------------------------------------------------
   pvalue_fun <-
     pvalue_fun %||%
@@ -119,48 +128,82 @@ tbl_uvregression <- function(data, method, y = NULL, x = NULL, method.args = NUL
     conf.level %||%
     getOption("gtsummary.conf.level", default = 0.95)
 
-  # bare to string -------------------------------------------------------------
+  # bare to string/enexpr ------------------------------------------------------
   # updated method and y inputs to be bare, and converting them to strings
   # to be compatible with the rest of the function that assumes character input
-  method <- deparse(substitute(method)) %>% as.character()
-  y_name <- deparse(substitute(y)) %>% as.character()
-  x_name <- deparse(substitute(x)) %>% as.character()
-  if (!rlang::quo_is_null(rlang::enquo(y))) y <- y_name
-  if (!rlang::quo_is_null(rlang::enquo(x))) x <- x_name
+  method <- rlang::enexpr(method)
+  method.args <- rlang::enexpr(method.args)
+
+  # converting to string, or keeping as NULL.  Using the standard
+  # variable selector, but users may also pass `Surv(ttdeath, death)`,
+  # which is not a column header, rather a function.  In that case,
+  # converting the bare input to a string.
+  x <- rlang::enexpr(x)
+  y <- rlang::enexpr(y)
+  x <-
+    tryCatch({
+      var_input_to_string(data = data, select_input = !!x, arg_name = "x")
+    }, error = function(e) {
+      rlang::expr_text(x)
+    })
+  y <-
+    tryCatch({
+      var_input_to_string(data = data, select_input = !!y, arg_name = "y")
+    }, error = function(e) {
+      rlang::expr_text(y)
+    })
+
+  # checking selections of x and y
   if (is.null(x) + is.null(y) != 1L) {
     stop("Specify one, and only one, of `x` and `y`. This function can
          create univariate regression models holding either a covariate or outcome
-         constant.")
+         constant.", call. = FALSE)
+  }
+  if ((!is.null(x) && length(x) != 1) | (!is.null(y) && length(y) != 1)) {
+    stop("Select only a single column in argument `x=` or `y=`.", call. = FALSE)
   }
 
+  include <- var_input_to_string(data = data, select_input = !!rlang::enquo(include),
+                                 arg_name = "include")
+  exclude <- var_input_to_string(data = data, select_input = !!rlang::enquo(exclude),
+                                 arg_name = "exclude")
+  show_single_row <- var_input_to_string(data = data,
+                                         select_input = !!rlang::enquo(show_single_row),
+                                         arg_name = "show_single_row")
+
   # checking formula correctly specified ---------------------------------------
+  if (!rlang::is_string(formula)) {
+    stop('`formula` must be passed as a string, e.g. `formula = "{y} ~ {x}"`',
+         call. = FALSE)
+  }
   # checking that '{x}' appears on RHS of formula
   if (word(formula, start = 2L, sep = fixed("~")) %>%
     str_detect(pattern = fixed("{x}")) == FALSE) {
-    stop("'{x}' must appear on RHS of '~' in formula argument")
+    stop("'{x}' must appear on RHS of '~' in formula argument", call. = FALSE)
   }
   # checking that '{y}' appears on LHS of formula
   if (word(formula, start = 1L, sep = fixed("~")) %>%
     str_detect(pattern = fixed("{y}")) == FALSE) {
-    stop("'{y}' must appear on LHS of '~' in formula argument")
+    stop("'{y}' must appear on LHS of '~' in formula argument", call. = FALSE)
   }
 
   # checking estimate_fun and pvalue_fun are functions -------------------------
   if (!is.function(estimate_fun) | !is.function(pvalue_fun)) {
-    stop("Arguments 'estimate_fun' and 'pvalue_fun' must be functions.")
+    stop("Arguments 'estimate_fun' and 'pvalue_fun' must be functions.",
+         call. = FALSE)
   }
 
   # converting tidyselect formula lists to named lists -------------------------
-  label <- tidyselect_to_list(data, label, .meta_data = NULL, input_type = "label")
+  label <- tidyselect_to_list(data, label, .meta_data = NULL, arg_name = "label")
   # all sepcifed labels must be a string of length 1
   if (!every(label, ~ rlang::is_string(.x))) {
-    stop("Each `label` specified must be a string of length 1.")
+    stop("Each `label` specified must be a string of length 1.", call. = FALSE)
   }
 
   # data -----------------------------------------------------------------------
   # data is a data frame
   if (!is.data.frame(data)) {
-    stop("'data' input must be a data frame.")
+    stop("`data` argument must be a data frame.", call. = FALSE)
   }
 
   # will return call, and all object passed to in table1 call
@@ -182,203 +225,101 @@ tbl_uvregression <- function(data, method, y = NULL, x = NULL, method.args = NUL
   if (!is.null(include)) all_vars <- intersect(all_vars, include)
   all_vars <- all_vars %>% setdiff(exclude)
   if (length(all_vars) == 0) {
-    stop("There were no covariates selected.")
+    stop("There were no covariates selected.", call. = FALSE)
   }
 
   # bulding regression models --------------------------------------------------
-  if (is.null(x)) {
-    model_obj_list <-
-      map(
-        all_vars,
-        function(x) {
-          do.call(
-            what = method,
-            args = c(
-              list(
-                formula = glue(formula) %>% stats::as.formula(),
-                data = data
-              ),
-              method.args
-            )
-          )
-        }
+  df_model <-
+    tibble(vars = all_vars) %>%
+    set_names(ifelse(!is.null(y), "x", "y")) %>%
+    mutate(
+      formula_chr = glue(formula),
+      model = map(
+        .data$formula_chr,
+        ~list(method, formula = as.formula(.x), data = data) %>%
+          c(as.list(method.args)[-1]) %>%
+          as.call() %>%
+          eval()
       )
-  }
-  else if (is.null(y)) {
-    model_obj_list <-
-      map(
-        all_vars,
-        function(y) {
-          do.call(
-            what = method,
-            args = c(
-              list(
-                formula = glue(formula) %>% stats::as.formula(),
-                data = data
-              ),
-              method.args
-            )
-          )
-        }
-      )
-  }
-  names(model_obj_list) <- all_vars
+    )
 
-  # formatting regression models with tbl_regression ---------------------------
-  if (is.null(x)) {
-    tbl_regression_list <-
-      imap(
-        model_obj_list,
-        ~ tbl_regression(
-          .x,
-          exponentiate = exponentiate,
-          conf.level = conf.level,
-          label = label,
-          show_single_row = intersect(.y, show_single_row),
-          tidy_fun = tidy_fun
+  # convert model to tbl_regression object -------------------------------------
+  if (!is.null(y)) {
+    df_model <-
+      df_model %>%
+      mutate(
+        tbl = map2(
+          .data$model, .data$x,
+          ~tbl_regression(
+            .x,
+            exponentiate = exponentiate,
+            conf.level = conf.level,
+            label = label,
+            show_single_row = intersect(.y, show_single_row),
+            tidy_fun = tidy_fun
+          )
         )
       )
   }
-  else if (is.null(y)) {
-    tbl_regression_list <-
-      imap(
-        model_obj_list,
-        function(tbl, var) {
-          tbl_uv <-
-            tbl_regression(
-              tbl,
-              label = list(label[[var]] %||% attr(data[[var]], "label") %||% var) %>% set_names(x),
-              exponentiate = exponentiate,
-              conf.level = conf.level,
-              include = x,
-              show_single_row = show_single_row,
-              tidy_fun = tidy_fun
-            )
-          tbl_uv$table_body$variable <- var
-          tbl_uv$table_body$var_type <- NA_character_
-          tbl_uv
-        }
+  if (!is.null(x)) {
+    df_model <-
+      df_model %>%
+      mutate(
+        tbl = map2(
+          .data$model, .data$y,
+          function(model, y) {
+            tbl_uv <-
+              tbl_regression(
+                model,
+                label = list(label[[y]] %||% attr(data[[y]], "label") %||% y) %>% set_names(x),
+                exponentiate = exponentiate,
+                conf.level = conf.level,
+                include = x,
+                show_single_row = show_single_row,
+                tidy_fun = tidy_fun
+              )
+            tbl_uv$table_body$variable <- y
+            tbl_uv$table_body$var_type <- NA_character_
+            tbl_uv
+          }
+        )
       )
   }
 
-  # extracting model tables and stacking
-  table_body <-
-    map_dfr(
-      tbl_regression_list,
-      ~ .x %>% pluck("table_body")
-    ) %>%
-    mutate(
-      N = if_else(.data$row_type == "label", .data$N, NA_integer_)
-    )
-
-  # column labels
-  # table of column headers
-  table_header <-
-    tibble(column = names(table_body)) %>%
-    left_join(tbl_regression_list %>% pluck(1, "table_header"),
-      by = "column"
-    )
-
-  # creating a meta_data table (this will be used in subsequent functions, eg add_global_p)
-  meta_data <-
-    table_body %>%
-    filter(!!parse_expr('row_type == "label"')) %>%
-    select(c("variable", "var_type", "label", "N"))
-
-  # returning named list of results
-  results <- list(
-    inputs = tbl_uvregression_inputs,
-    tbl_regression_list = tbl_regression_list,
-    meta_data = meta_data,
-    table_body = table_body,
-    table_header = table_header,
-    call_list = list(tbl_uvregression = match.call()),
-    gt_calls = eval(gt_tbl_uvregression),
-    kable_calls = eval(kable_tbl_uvregression)
-  )
-
-  # column headers
-  results <- modify_header_internal(
-    results,
-    label = ifelse(!is.null(y), "**Covariate**", "**Outcome**"),
-    estimate = glue("**{estimate_header(model_obj_list[[1]], exponentiate)}**"),
-    ci = glue("**{style_percent(conf.level, symbol = TRUE)} CI**"),
-    p.value = "**p-value**"
-  )
-
-  # unhiding N column and assigning label, if requested
+  # adding N to table ----------------------------------------------------------
   if (hide_n == FALSE) {
-    results <- modify_header_internal(
-      results,
-      N = "**N**",
-    )
+    df_model <-
+      df_model %>%
+      mutate(
+        tbl = map(
+          .data$tbl,
+          function(tbl) {
+            tbl <- modify_header(tbl, N = "**N**")
+            # only display N on label row
+            tbl$table_body$N <- ifelse(tbl$table_body$row_type == "label",
+                                       tbl$table_body$N, NA)
+            tbl
+          }
+        )
+      )
   }
 
-  # writing additional gt and kable calls with data from table_header
-  results <- update_calls_from_table_header(results)
+  # stacking results to return -------------------------------------------------
+  results <- tbl_stack(df_model$tbl)
+  names(results$tbls) <- all_vars
+  class(results) <- c("tbl_uvregression", "gtsummary")
+
+  # creating a meta_data table -------------------------------------------------
+  # (this will be used in subsequent functions, eg add_global_p)
+  results$meta_data <-
+    results$table_body %>%
+    filter(.data$row_type == "label") %>%
+    select(c("variable", "var_type", "label", "N"))
+
+  # exporting results ----------------------------------------------------------
+  results$inputs <- tbl_uvregression_inputs
+  results$call_list = list(tbl_uvregression = match.call())
 
-  class(results) <- "tbl_uvregression"
   results
 }
 
-
-# gt function calls ------------------------------------------------------------
-# quoting returns an expression to be evaluated later
-gt_tbl_uvregression <- quote(list(
-  # first call to the gt function
-  gt = "gt::gt(data = x$table_body)" %>%
-    glue(),
-
-  # label column indented and left just
-  cols_align = glue(
-    "gt::cols_align(align = 'center') %>% ",
-    "gt::cols_align(align = 'left', columns = gt::vars(label))"
-  ),
-
-  # NAs do not show in table
-  fmt_missing =
-    "gt::fmt_missing(columns = gt::everything(), missing_text = '')" %>%
-      glue(),
-
-  # Show "---" for reference groups
-  fmt_missing_ref =
-    "gt::fmt_missing(columns = gt::vars(estimate, ci), rows = row_ref == TRUE, missing_text = '---')" %>%
-      glue(),
-
-  # indenting levels and missing rows
-  tab_style_text_indent = glue(
-    "gt::tab_style(",
-    "style = gt::cell_text(indent = gt::px(10), align = 'left'),",
-    "locations = gt::cells_data(",
-    "columns = gt::vars(label), ",
-    "rows = row_type != 'label'",
-    "))"
-  )
-))
-
-# kable function calls ------------------------------------------------------------
-# quoting returns an expression to be evaluated later
-kable_tbl_uvregression <- quote(list(
-  # first call to the gt function
-  kable = glue("x$table_body"),
-
-  #  placeholder, so the formatting calls are performed other calls below
-  fmt = NULL,
-
-  # Show "---" for reference groups
-  fmt_missing_ref = glue(
-    "dplyr::mutate_at(dplyr::vars(estimate, conf.low), ",
-    "~ dplyr::case_when(row_ref == TRUE ~ '---', TRUE ~ .))"
-  )
-))
-
-
-# helper function to remove one value of "x" from a vector
-remove_one_x <- function(v) {
-  index_remove <-
-    (v == "x") %>%
-    which() %>%
-    min()
-
-  v[-index_remove]
-}
