@@ -1,11 +1,11 @@
 #' Tidies regression object based on class
 #'
 #' The `tidy_wrap()` function has two primary functions.  First, using either
-#' `broom::tidy` or `broom.mixed::tidy` (depending on model input class)
+#' `broom::tidy`
 #' the regression model object is converted into a data frame. It then adjusts the
 #' output for use in the rest of \code{\link{tbl_regression}}.
 #'
-#' The output of `broom::tidy` or `broom.mixed::tidy` will often include additional information
+#' The output of `broom::tidy` will often include additional information
 #' that will not be included in a printed table from `tbl_regression()`
 #' (e.g. scale parameters, random effects, etc.).  This
 #' simple helper function deletes extraneous rows from the output.
@@ -14,9 +14,7 @@
 #'
 #' @param x regression model object
 #' @param exponentiate logical argument passed directly to `broom::tidy`
-#' or `broom.mixed::tidy`.
 #' @param conf.level confidence level passed directly to `broom::tidy`
-#' or `broom.mixed::tidy`.
 #' @param tidy_fun tidy function and arguments passed to it
 #' @noRd
 #' @keywords internal
@@ -26,52 +24,70 @@
 tidy_wrap <- function(x, exponentiate, conf.level, tidy_fun) {
   mixed_classes <- c("lmerMod", "glmerMod")
   if (is.null(tidy_fun)) {
-    if (class(x)[1] %in% mixed_classes) { # can add other classes later. Need exact subclass.
-      tidy_bit <- broom.mixed::tidy(
+    if (inherits(x, mixed_classes)) { # can add other classes later. Need exact subclass.
+      tryCatch({
+        tidy_bit <- broom::tidy(
         x,
         exponentiate = exponentiate,
         conf.level = conf.level, conf.int = TRUE, effects = "fixed"
       )
+      },
+      error = function(e) {
+        usethis::ui_oops(paste0(
+          "There was an error calling {usethis::ui_code('broom::tidy(x, conf.int = TRUE, effects = \"fixed\")')},\n",
+          "which is required for gtsummary to print the model summary.\n",
+          "See error message below. \n"
+        ))
+        stop(as.character(e), call. = FALSE)
+      }
+      )
     }
 
-    if (!(class(x)[1] %in% mixed_classes)) {
-      tidy_bit <- broom::tidy(
+    if (!inherits(x, mixed_classes)) {
+      tryCatch({
+        tidy_bit <- broom::tidy(
         x,
         exponentiate = exponentiate,
         conf.level = conf.level, conf.int = TRUE
       )
+      },
+      error = function(e) {
+        usethis::ui_oops(paste0(
+          "There was an error calling {usethis::ui_code('broom::tidy(x, conf.int = TRUE)')},\n",
+          "which is required for gtsummary to print the model summary.\n",
+          "See error message below. \n"
+        ))
+        stop(as.character(e), call. = FALSE)
+      }
+      )
     }
 
     # deleting scale parameters from survreg objects
-    if (class(x)[1] == "survreg") {
-      return(
-        tidy_bit %>%
-          filter(!!parse_expr('term != "Log(scale)"'))
-      )
+    if (inherits(x, "survreg")) {
+      tidy_bit <- tidy_bit %>%
+        filter(.data$term != "Log(scale)")
     }
   }
 
   # if user specified a tidier use it here.
   if (!is.null(tidy_fun)) {
-    tryCatch(
-      {
+    tryCatch({
         tidy_bit <- do.call(
           tidy_fun,
           args = list(x,
             exponentiate = exponentiate,
-            conf.level = conf.level, conf.int = T
+            conf.level = conf.level, conf.int = TRUE
           )
         )
       },
       error = function(e) {
         usethis::ui_oops(paste0(
           "There was an error calling {usethis::ui_code('tidy_fun')}.\n",
-          "Most likely, this is because the argument passed in {usethis::ui_code('tidy_fun = ')} \n",
+          "Most likely, this is because the argument passed in {usethis::ui_code('tidy_fun=')} \n",
           "was\nmisspelled, does not exist, is not compatible with your object, \n",
           "or was missing necessary arguments. See error message below. \n"
         ))
-        print(e)
-        stop(e)
+        stop(as.character(e), call. = FALSE)
       }
     )
   }
@@ -92,16 +108,18 @@ tidy_wrap <- function(x, exponentiate, conf.level, tidy_fun) {
 #' @param tidy broom tidy result
 #' @inheritParams tbl_regression
 #' @noRd
-#' @importFrom stringr fixed str_detect
 #' @keywords internal
 
 parse_fit <- function(fit, tidy, label, show_single_row) {
+  # enquos ---------------------------------------------------------------------
+  show_single_row <- rlang::enquo(show_single_row)
+
   # extracting model frame
   model_frame <- stats::model.frame(fit)
 
   # add a check on what the model.frame output is and print a message if it's not
   # a data.frame with all vector columns
-  if (!(all("data.frame" %in% class(model_frame) && all(purrr::map_lgl(model_frame, ~ rlang::is_vector(.x)))))) {
+  if (!(all(inherits(model_frame, "data.frame") && all(purrr::map_lgl(model_frame, ~ rlang::is_vector(.x)))))) {
     message(paste0(
       "Model input `x` has an unexpected format for `model.frame(x)` \n",
       " which may affect `tbl_regression()` output.\n",
@@ -198,8 +216,7 @@ parse_fit <- function(fit, tidy, label, show_single_row) {
   # more  var labels -----------------------------------------------------------
   # model.frame() strips variable labels from cox models.  this attempts
   # to grab the labels in another way
-  labels_parent_frame <- tryCatch(
-    {
+  labels_parent_frame <- tryCatch({
       stats::model.frame.default(fit) %>%
         purrr::imap(~ attr(.x, "label"))
     },
@@ -234,23 +251,34 @@ parse_fit <- function(fit, tidy, label, show_single_row) {
       # matching the variable name to each term in the model
       variable = map_chr(
         .data$term_split,
-        ~ term_match %>%
+        ~ stats::na.omit(term_match) %>%
           filter(.data$term == .x) %>%
           pull(.data$variable) %>%
-          {
-            ifelse(.x == "(Intercept)", NA, .)
-          }
-      ),
+          {ifelse(length(.) == 0, .x, .)} # for unmatched terms, using term as variable
+      )
+    )
+
+  # adding variable labels -----------------------------------------------------
+  label <- tidyselect_to_list(.data = vctr_2_tibble(unique(tidy_long$variable)),
+                              x = label, arg_name = "label")
+  # # all sepcifed labels must be a string of length 1
+  if (!every(label, ~ rlang::is_string(.x))) {
+    stop("Each `label` specified must be a string of length 1.", call. = FALSE)
+  }
+
+  tidy_long_lbl <-
+    tidy_long %>%
+    mutate(
       # variable labels
       variable_lbl = map_chr(
         .data$variable,
         ~ label[[.x]] %||% attr(model_frame[[.x]], "label") %||%
           labels_parent_frame[[.x]] %||% .x
       ),
-      variable_lbl = ifelse(is.na(.data$variable_lbl) & .data$term == "(Intercept)",
-        "(Intercept)",
-        .data$variable_lbl
-      ),
+      # variable_lbl = ifelse(is.na(.data$variable_lbl) & .data$term == "(Intercept)",
+      #   "(Intercept)",
+      #   .data$variable_lbl
+      # ),
       # indicating whether each variable is categorical or continuous
       variable_type = map_chr(
         .data$variable,
@@ -276,14 +304,14 @@ parse_fit <- function(fit, tidy, label, show_single_row) {
   # tidy_term ------------------------------------------------------------------
   # one line per term in the model
   tidy_term <-
-    tidy_long %>%
+    tidy_long_lbl %>%
     group_by(.data$term_id, .data$term) %>%
     mutate(
       # indicating whether obs is an interaction term or not
       interaction = n() > 1,
       # groups are terms that belong to the same variable (or interaction set)
       group = .data$variable %>% paste(collapse = ":"),
-      group = ifelse(.data$term == "(Intercept)" & is.na(.data$variable), "(Intercept)", .data$group),
+      # group = ifelse(.data$term == "(Intercept)" & is.na(.data$variable), "(Intercept)", .data$group),
       # the collpase only comes into play when there are interactions present
       group_lbl = .data$variable_lbl %>% paste(collapse = " * "),
       level_lbl = .data$level %>% paste(collapse = " * "),
@@ -295,6 +323,11 @@ parse_fit <- function(fit, tidy, label, show_single_row) {
     distinct()
 
   # tidy_group -----------------------------------------------------------------
+  show_single_row <-
+    var_input_to_string(data = vctr_2_tibble(unique(tidy_term$group)),
+                        arg_name = "show_single_row",
+                        select_input = !!show_single_row)
+
   # groups are terms that belong to the same variable (or interaction set)
   tidy_group <-
     tidy_term %>%
@@ -328,18 +361,6 @@ parse_fit <- function(fit, tidy, label, show_single_row) {
       )
     )
 
-  # show_single_row check ------------------------------------------------------
-  # checking that all variables listed in show_single_row appear in results
-  for (i in show_single_row) {
-    if (!i %in% tidy_group$group) {
-      stop(glue(
-        "'{i}' from argument 'show_single_row' is not a variable ",
-        "from the model. Select from:\n",
-        "{paste(tidy_group$group %>% setdiff('(Intercept)'), collapse = ', ')}"
-      ))
-    }
-  }
-
   # check that all variables in show_single_row are dichotomous
   bad_show_single_row <-
     tidy_group %>%
@@ -354,8 +375,8 @@ parse_fit <- function(fit, tidy, label, show_single_row) {
   if (length(bad_show_single_row) > 0) {
     stop(glue(
       "'{paste(bad_show_single_row, collapse = \"', '\")}' from argument ",
-      "'show_single_row' may only be applied to binary variables."
-    ))
+      "'show_single_row' may only be applied to dichotomous variables."
+    ), call. = FALSE)
   }
 
   # final touches to result ----------------------------------------------------
@@ -455,27 +476,17 @@ parse_final_touches <- function(group, group_lbl, single_row, var_type, data, mo
     ))
 }
 
-#' @title Vetted tidy models
+#' Takes a vector and transforms to data frame with those column names
 #'
-#' @description Below is a list of models vetted for use
-#' in [tbl_regression] and [tbl_uvregression].  If a model is passed to these
-#' functions and the model is not listed below and  a `tidy()` function is
-#' not specified in the `tidy_fun=` argument, the model object will be passed
-#' to [broom::tidy].
-#'
-#' \itemize{
-#'  \item{[stats::lm]}
-#'  \item{[stats::glm]}
-#'  \item{[survival::coxph]}
-#'  \item{[survival::survreg]}
-#'  \item{[lme4::glmer]}
-#'  \item{[lme4::lmer]}
-#'  \item{[geepack::geeglm]}
-#' }
-#' @name tidy_vetted
-#' @section model support:
-#' If [broom::tidy] or [broom.mixed::tidy] support a class of model not listed
-#' above, please submit a [GitHub Issue](https://github.com/ddsjoberg/gtsummary/issues).
-#' The model can be added to the list of vetted models and unit tests will be
-#' put in place to ensure continued support for the model.
-NULL
+#' This will be used for tidyselect to used those functions to select from
+#' the vector
+#' @noRd
+#' @keywords internal
+vctr_2_tibble <- function(x) {
+  n <- length(x)
+  matrix(ncol = n) %>%
+    tibble::as_tibble(.name_repair = "minimal") %>%
+    rlang::set_names(x) %>%
+    dplyr::slice(0)
+}
+
