@@ -4,7 +4,7 @@ test_that("auto-assign continuous: mtcars$hp", {
   expect_equal(
     assign_summary_type(
       data = mtcars, variable = "hp",
-      class = class(mtcars$hp), summary_type = NULL
+      class = class(mtcars$hp), summary_type = NULL, value = NULL
     ),
     "continuous"
   )
